﻿using System.Collections.Generic;
using System.Globalization;
using System.Linq;
using System.Threading;
using System.Windows;
using System.Windows.Controls;
using UnitConvertor.Translation;
using UnitConvertor.UnitConvertorBase;
using UnitConvertor.UnitConvertorEnums;

namespace UnitConvertor.UnitConvertorWindow
{
    /// <summary>
    /// Interaction logic for UnitConvertWindow.xaml
    /// </summary>
    public partial class UnitConvertWindow : Window
    {
        private ConvertorInitializer converter;
        private ConversionType conversionType;
        private MainWindowViewModel model = new MainWindowViewModel();
        public UnitConvertWindow()
        {
            InitializeComponent();          
            DataContext = model;
            InitializeConverters();
            HideComboBoxes();
        }

        private void InitializeConverters()
        {
            converter = new ConvertorInitializer();
        }

        private CultureInfo GetCurrentCulture()
        {
            return Thread.CurrentThread.CurrentCulture;
        }

        private void SetCulture()
        {
            List<CultureInfo> languagesList = model.Languages.Cast<CultureInfo>().ToList();
            if (GetCurrentCulture().Name == "sk-SK" || GetCurrentCulture().Name == "cs-CZ")
            {                
                ComboBoxLanguages.SelectedItem = languagesList[0];
            }
            else
            {
                ComboBoxLanguages.SelectedItem = languagesList[1];     
            }
            
        }

        private void HideComboBoxes()
        {
            ComboBoxLengthFromUnit.Visibility = Visibility.Hidden;
            ComboBoxLengthToUnit.Visibility = Visibility.Hidden;
            ComboBoxTransferFromUnit.Visibility = Visibility.Hidden;
            ComboBoxTransferToUnit.Visibility = Visibility.Hidden;
            ComboBoxWeightFromUnit.Visibility = Visibility.Hidden;
            ComboBoxWeightToUnit.Visibility = Visibility.Hidden;

            ComboBoxLengthFromUnit.SelectedItem = Length.Milimeter;
            ComboBoxLengthToUnit.SelectedItem = Length.Milimeter;
            ComboBoxTransferFromUnit.SelectedItem = TransferRate.Byte;
            ComboBoxTransferToUnit.SelectedItem = TransferRate.Byte;
            ComboBoxWeightFromUnit.SelectedItem = Weight.Gram;
            ComboBoxWeightToUnit.SelectedItem = Weight.Gram;
        }

        private void ButtonConvert_Click(object sender, RoutedEventArgs e)
        {
            ForceValidation();
            float toConvertValue;
            var inputValue = float.TryParse(TextBoxFrom.Text, out toConvertValue);
            if (inputValue)
            {
                object fromUnit = null;
                object toUnit = null;
                switch (conversionType)
                {
                    case ConversionType.Length:
                        fromUnit = ComboBoxLengthFromUnit.SelectedItem;
                        toUnit = ComboBoxLengthToUnit.SelectedItem;
                        if (fromUnit == null || toUnit == null)
                        {
                            break;
                        }
                        TextBoxTo.Text = converter.Lengthconverter.Convert(toConvertValue, (Length)fromUnit, (Length)toUnit).ToString(CultureInfo.InvariantCulture);                        
                        break;
                    case ConversionType.Weight:
                        fromUnit = GetSelectedItem(ComboBoxWeightFromUnit);
                        toUnit = GetSelectedItem(ComboBoxWeightToUnit);
                        if (fromUnit == null || toUnit == null)
                        {
                            break;
                        }
                        TextBoxTo.Text = converter.WeightConverter.Convert(toConvertValue, (Weight)fromUnit, (Weight)toUnit).ToString(CultureInfo.InvariantCulture);
                        break;
                    case ConversionType.TransferRate:
                        fromUnit = GetSelectedItem(ComboBoxTransferFromUnit);
                        toUnit = GetSelectedItem(ComboBoxTransferToUnit);
                        if (fromUnit == null || toUnit == null)
                        {
                            break;
                        }
                        TextBoxTo.Text = converter.TransferRateConverter.Convert(toConvertValue, (TransferRate)fromUnit, (TransferRate)toUnit).ToString(CultureInfo.InvariantCulture);
                        break;
                }
            }
        }

        private void RadioButtonLength_OnClick(object sender, RoutedEventArgs e)
        {
            conversionType = ConversionType.Length;
            ComboBoxLengthFromUnit.Visibility = Visibility.Visible;
            ComboBoxLengthToUnit.Visibility = Visibility.Visible;
            ComboBoxTransferFromUnit.Visibility = Visibility.Hidden;
            ComboBoxTransferToUnit.Visibility = Visibility.Hidden;
            ComboBoxWeightFromUnit.Visibility = Visibility.Hidden;
            ComboBoxWeightToUnit.Visibility = Visibility.Hidden;
        }

        private void RadioButtonWeight_OnClick(object sender, RoutedEventArgs e)
        {
            conversionType = ConversionType.Weight;
            ComboBoxWeightFromUnit.Visibility = Visibility.Visible;
            ComboBoxWeightToUnit.Visibility = Visibility.Visible;
            ComboBoxLengthFromUnit.Visibility = Visibility.Hidden;
            ComboBoxLengthToUnit.Visibility = Visibility.Hidden;
            ComboBoxTransferFromUnit.Visibility = Visibility.Hidden;
            ComboBoxTransferToUnit.Visibility = Visibility.Hidden;
        }

        private void RadioButtonTransferRate_OnClick(object sender, RoutedEventArgs e)
        {
            conversionType = ConversionType.TransferRate;
            ComboBoxTransferFromUnit.Visibility = Visibility.Visible;
            ComboBoxTransferToUnit.Visibility = Visibility.Visible;
            ComboBoxWeightFromUnit.Visibility = Visibility.Hidden;
            ComboBoxWeightToUnit.Visibility = Visibility.Hidden;
            ComboBoxLengthFromUnit.Visibility = Visibility.Hidden;
            ComboBoxLengthToUnit.Visibility = Visibility.Hidden;
        }

        private void ForceValidation()
        {
            var bindingExpression = TextBoxFrom.GetBindingExpression(TextBox.TextProperty);
            if (bindingExpression != null)
            {
                bindingExpression.UpdateSource();
            }
                
        }

        private object GetSelectedItem(ComboBox box)
        {
            return box.SelectedItem;
        }

        private void ComboBoxLanguages_Loaded(object sender, RoutedEventArgs e)
        {
            SetCulture();
        }
    }
}
